@@ -1,11 +1,16 @@
 # -*- coding: utf-8 -*-
 
 import requests
+try:
+    from requests.packages.urllib3 import fields
+except ImportError:
+    fields = None
 import telebot
 from telebot import types
 from telebot import util
 
 logger = telebot.logger
+req_session = requests.session()
 
 API_URL = "https://api.telegram.org/bot{0}/{1}"
 FILE_URL = "https://api.telegram.org/file/bot{0}/{1}"
@@ -28,10 +33,12 @@ def _make_request(token, method_name, method='get', params=None, files=None, bas
     logger.debug("Request: method={0} url={1} params={2} files={3}".format(method, request_url, params, files))
     read_timeout = READ_TIMEOUT
     connect_timeout = CONNECT_TIMEOUT
+    if files and fields:
+        fields.format_header_param = _no_encode(fields.format_header_param)
     if params:
         if 'timeout' in params: read_timeout = params['timeout'] + 10
         if 'connect-timeout' in params: connect_timeout = params['connect-timeout'] + 10
-    result = requests.request(method, request_url, params=params, files=files, timeout=(connect_timeout, read_timeout))
+    result = req_session.request(method, request_url, params=params, files=files, timeout=(connect_timeout, read_timeout))
     logger.debug("The server returned: '{0}'".format(result.text.encode('utf8')))
     return _check_result(method_name, result)['result']
 
@@ -80,7 +87,7 @@ def get_file(token, file_id):
 
 def download_file(token, file_path):
     url = FILE_URL.format(token, file_path)
-    result = requests.get(url)
+    result = req_session.get(url)
     if result.status_code != 200:
         msg = 'The server returned HTTP {0} {1}. Response body:\n[{2}]' \
             .format(result.status_code, result.reason, result.text)
@@ -567,6 +574,15 @@ def _convert_markup(markup):
     return markup
 
 
+def _no_encode(func):
+    def wrapper(key, val):
+        if key == 'filename':
+            return '{0}={1}'.format(key, val)
+        else:
+            return func(key, val)
+    return wrapper
+
+
 class ApiException(Exception):
     """
     This class represents an Exception thrown when a call to the Telegram API fails.
